summaryrefslogtreecommitdiff
path: root/internal/executor/executor.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/executor/executor.go')
-rw-r--r--internal/executor/executor.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/internal/executor/executor.go b/internal/executor/executor.go
index 7213b34..9052bd7 100644
--- a/internal/executor/executor.go
+++ b/internal/executor/executor.go
@@ -512,13 +512,13 @@ func (p *Pool) triggerStoryDeploy(ctx context.Context, storyID string) {
if proj.DeployScript == "" {
return
}
// Merge story branch to master before deploying (ADR-007).
if story.BranchName != "" && proj.LocalPath != "" {
mergeSteps := [][]string{
{"git", "-C", proj.LocalPath, "fetch", "origin"},
- {"git", "-C", proj.LocalPath, "checkout", "master"},
+ {"git", "-C", proj.LocalPath, "checkout", "main"},
{"git", "-C", proj.LocalPath, "merge", "--no-ff", story.BranchName, "-m", "Merge " + story.BranchName},
- {"git", "-C", proj.LocalPath, "push", "origin", "master"},
+ {"git", "-C", proj.LocalPath, "push", "origin", "main"},
}
for _, args := range mergeSteps {
if mergeOut, mergeErr := exec.CommandContext(ctx, args[0], args[1:]...).CombinedOutput(); mergeErr != nil {
@@ -526,7 +526,7 @@ func (p *Pool) triggerStoryDeploy(ctx context.Context, storyID string) {
return
}
}
- p.logger.Info("story branch merged to master", "storyID", storyID, "branch", story.BranchName)
+ p.logger.Info("story branch merged to main", "storyID", storyID, "branch", story.BranchName)
}
out, err := exec.CommandContext(ctx, proj.DeployScript).CombinedOutput()
if err != nil {
@@ -512,13 +512,13 @@ func (p *Pool) triggerStoryDeploy(ctx context.Context, storyID string) {
return
}
- // Merge story branch to master before deploying (ADR-007).
+ // Merge story branch to main before deploying (ADR-007).
if story.BranchName != "" && proj.LocalPath != "" {
mergeSteps := [][]string{